/*
 * hdf5-file.h
 *
 * Read/write HDF5 data files
 *
 * Copyright © 2012-2014 Deutsches Elektronen-Synchrotron DESY,
 *                       a research centre of the Helmholtz Association.
 *
 * Authors:
 *   2009-2014 Thomas White <taw@physics.org>
 *
 * This file is part of CrystFEL.
 *
 * CrystFEL is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * CrystFEL is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CrystFEL.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#ifndef HDF5_H
#define HDF5_H

#include <stdint.h>
#include <hdf5.h>

struct hdfile;
struct copy_hdf5_field;

#include "image.h"

#ifdef __cplusplus
extern "C" {
#endif

extern int hdf5_write(const char *filename, const void *data,
                      int width, int height, int type);

extern int hdf5_write_image(const char *filename, struct image *image);

extern int hdf5_read(struct hdfile *f, struct image *image, int satcorr);

extern struct hdfile *hdfile_open(const char *filename);
extern int hdfile_set_image(struct hdfile *f, const char *path);
extern int16_t *hdfile_get_image_binned(struct hdfile *hdfile,
                                         int binning, int16_t *maxp);
extern char **hdfile_read_group(struct hdfile *f, int *n, const char *parent,
                                int **p_is_group, int **p_is_image);
extern int hdfile_set_first_image(struct hdfile *f, const char *group);
extern void hdfile_close(struct hdfile *f);

extern int hdfile_is_scalar(struct hdfile *f, const char *name, int verbose);
extern char *hdfile_get_string_value(struct hdfile *f, const char *name);
extern int get_peaks(struct image *image, struct hdfile *f, const char *p);
extern double get_value(struct hdfile *f, const char *name);

extern struct copy_hdf5_field *new_copy_hdf5_field_list(void);
extern void free_copy_hdf5_field_list(struct copy_hdf5_field *f);
extern void copy_hdf5_fields(struct hdfile *f,
                             const struct copy_hdf5_field *copyme, FILE *fh);
extern void add_copy_hdf5_field(struct copy_hdf5_field *copyme,
                                const char *name);

#ifdef __cplusplus
}
#endif

#endif	/* HDF5_H */
